/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef ORIENT_UTILS_H_
#define ORIENT_UTILS_H_

#include <camera.h>
#include <recorder.h>
#include <app_common.h>
#include <Elementary.h>

/**
 * @brief Normalize degree to 0-270
 * @param[in] degree
 * @return Normalized degree
 */
int orient_utils_normalize_degree(int degree);

/**
 * @brief Calculates video recorder orientation
 * @param[in] dev_orient device(window) orientation in degrees
 * @param[in] lens_orient lens orientation in degrees
 * @return calculated orientation in degrees
 */
int orient_utils_get_rec_orient(int dev_orient, int lens_orient);

/**
 * @brief Calculates camera orientation
 * @param[in] dev_orient device(window) orientation in degrees
 * @param[in] lens_orient lens orientation in degrees
 * @return calculated orientation in degrees
 */
int orient_utils_get_cam_orient(int dev_orient, int lens_orient);

/**
 * @brief Convert device orientation to degrees
 * @param[in] orient application device orientation(enum)
 * @return degrees(0-270)
 */
int orient_utils_dev_orient_to_degree(app_device_orientation_e orient);

/**
 * @brief Convert degrees to device orientation
 * @param[in] degrees degrees(0-270)
 * @return application device orientation(enum)
 */
app_device_orientation_e orient_utils_degree_to_dev_orient(int degree);

/**
 * @brief Convert camera rotation to degrees
 * @param[in] rot camera rotation(enum)
 * @return degrees(0-270)
 */
int orient_utils_cam_rot_to_degree(camera_rotation_e rot);

/**
 * @brief Convert degrees to camera rotation
 * @param[in] degrees degrees(0-270)
 * @return camera rotation(enum)
 */
camera_rotation_e orient_utils_degree_to_cam_rot(int degree);

/**
 * @brief Convert degrees to recorder rotation
 * @param[in] degrees degrees(0-270)
 * @return recorder rotation(enum)
 */
recorder_rotation_e orient_utils_degree_to_rec_rot(int degree);

/**
 * @brief Convert recorder rotation to degrees
 * @param[in] rot recorder rotation(enum)
 * @return degrees(0-270)
 */
int orient_utils_rec_rot_to_degree(recorder_rotation_e rot);

/**
 * @brief Convert degrees elm_image orientation
 * @param[in] degrees degrees(0-270)
 * @return elm_image orientation
 */
Elm_Image_Orient orient_utils_degree_to_img_orient(int degree);

/**
 * @brief Convert degrees to elm_camera_attr_tag_orientation_e
 * @param[in] degrees degrees(0-270)
 * @param[in] flipped true - image flipped, flase otherwise
 * @return camera_attr_tag_orientation_e
 */
camera_attr_tag_orientation_e orient_utils_degree_to_cam_attr(int degree, bool flipped);


#endif /* ORIENT_UTILS_H_ */
