/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "../inc/orient-utils.h"

#include <app.h>
#include <math.h>
#include <assert.h>
#include <stdbool.h>

static inline int _map(int orient, int x1, int x2, int x3, int x4,
								int y1, int y2, int y3, int y4);

static inline int _map(int orient, int x1, int x2, int x3, int x4,
								int y1, int y2, int y3, int y4)
{
	if (orient == x1) {
		return y1;
	} else if (orient == x2) {
		return y2;
	} else if (orient == x3) {
		return y3;
	} else if (orient == x4) {
		return y4;
	}
	assert(false);
	return y1;
}

int orient_utils_normalize_degree(int degree)
{
	int res = degree % 360;

	if (res < 0) {
		res = 360 + res;
	}

	return res;
}

int orient_utils_get_cam_orient(int dev_orient, int lens_orient)
{
	return orient_utils_normalize_degree(-dev_orient - lens_orient);
}

int orient_utils_get_rec_orient(int dev_orient, int lens_orient)
{
	return orient_utils_normalize_degree(dev_orient + lens_orient);
}

int orient_utils_dev_orient_to_degree(app_device_orientation_e orient)
{
	return _map(orient, APP_DEVICE_ORIENTATION_0, APP_DEVICE_ORIENTATION_90,
			APP_DEVICE_ORIENTATION_180, APP_DEVICE_ORIENTATION_270, 0, 90, 180, 270);
}

app_device_orientation_e orient_utils_degree_to_dev_orient(int orient)
{
	return _map(orient, 0, 90, 180, 270, APP_DEVICE_ORIENTATION_0,
			APP_DEVICE_ORIENTATION_90, APP_DEVICE_ORIENTATION_180, APP_DEVICE_ORIENTATION_270);
}

int orient_utils_cam_rot_to_degree(camera_rotation_e rot)
{
	return _map(rot, CAMERA_ROTATION_NONE, CAMERA_ROTATION_90,
			CAMERA_ROTATION_180, CAMERA_ROTATION_270, 0, 90, 180, 270);
}

camera_rotation_e orient_utils_degree_to_cam_rot(int degree)
{
	return _map(degree, 0, 90, 180, 270, CAMERA_ROTATION_NONE,
			CAMERA_ROTATION_90, CAMERA_ROTATION_180, CAMERA_ROTATION_270);
}

recorder_rotation_e orient_utils_degree_to_rec_rot(int degree)
{
	return _map(degree, 0, 90, 180, 270, RECORDER_ROTATION_NONE,
			RECORDER_ROTATION_90, RECORDER_ROTATION_180, RECORDER_ROTATION_270);
}

int orient_utils_rec_rot_to_degree(recorder_rotation_e rot)
{
	return _map(rot, RECORDER_ROTATION_NONE, RECORDER_ROTATION_90, RECORDER_ROTATION_180,
			RECORDER_ROTATION_270, 0, 90, 180, 270);
}

Elm_Image_Orient orient_utils_degree_to_img_orient(int degree)
{
	return _map(degree, 0, 90, 180, 270, ELM_IMAGE_ORIENT_0,
			ELM_IMAGE_ORIENT_90, ELM_IMAGE_ORIENT_180, ELM_IMAGE_ORIENT_270);
}

camera_attr_tag_orientation_e orient_utils_degree_to_cam_attr(int degree, bool flipped)
{
	if (flipped) {
		return _map(degree, 0, 90, 180, 270, CAMERA_ATTR_TAG_ORIENTATION_TOP_RIGHT,
				CAMERA_ATTR_TAG_ORIENTATION_RIGHT_BOTTOM, CAMERA_ATTR_TAG_ORIENTATION_BOTTOM_LEFT, CAMERA_ATTR_TAG_ORIENTATION_LEFT_TOP);
	} else {
		return _map(degree, 0, 90, 180, 270, CAMERA_ATTR_TAG_ORIENTATION_TOP_LEFT,
				CAMERA_ATTR_TAG_ORIENTATION_LEFT_BOTTOM, CAMERA_ATTR_TAG_ORIENTATION_BOTTOM_RIGHT, CAMERA_ATTR_TAG_ORIENTATION_RIGHT_TOP);
	}
}
